from pyiso20022.camt.camt_025_001_08.camt_025_001_08 import (
    AddressType2Code,
    AddressType3Choice,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Contact13,
    DateAndPlaceOfBirth1,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification23,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification3,
    GenericPersonIdentification2,
    LongPaymentIdentification4,
    MessageHeader9,
    NamePrefix2Code,
    OrganisationIdentification39,
    OrganisationIdentificationSchemeName1Choice,
    OriginalMessageAndIssuer1,
    OtherContact1,
    Party52Choice,
    PartyIdentification272,
    PaymentIdentification8Choice,
    PaymentInstrument1Code,
    PaymentOrigin1Choice,
    PersonIdentification18,
    PersonIdentificationSchemeName1Choice,
    PostalAddress27,
    PreferredContactMethod2Code,
    QueueTransactionIdentification1,
    Receipt6,
    ReceiptV08,
    RequestHandling3,
    RequestStatus1Choice,
    RequestType4Choice,
    ShortPaymentIdentification4,
    StatusReason6Choice,
    StatusReasonInformation14,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "AddressType2Code",
    "AddressType3Choice",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Contact13",
    "DateAndPlaceOfBirth1",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification23",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification3",
    "GenericPersonIdentification2",
    "LongPaymentIdentification4",
    "MessageHeader9",
    "NamePrefix2Code",
    "OrganisationIdentification39",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalMessageAndIssuer1",
    "OtherContact1",
    "Party52Choice",
    "PartyIdentification272",
    "PaymentIdentification8Choice",
    "PaymentInstrument1Code",
    "PaymentOrigin1Choice",
    "PersonIdentification18",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress27",
    "PreferredContactMethod2Code",
    "QueueTransactionIdentification1",
    "Receipt6",
    "ReceiptV08",
    "RequestHandling3",
    "RequestStatus1Choice",
    "RequestType4Choice",
    "ShortPaymentIdentification4",
    "StatusReason6Choice",
    "StatusReasonInformation14",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]
